<!-- block header -->
<nav class="navbar navbar-expand-xl border-bottom">
    <div class="container-fluid">
        {% if config.theme.logo %}
            <img class="logo" src="{{ config.theme.logo|url }}">
        {% endif %}

        {% if config.theme.components and config.theme.components.site_name == False %}
        {% else %}
            <span class="{{ config.theme.site_name_style }} fs-4 title-color site-name" id="component-site-name" style="text-transform: uppercase;">{{ config.site_name }}</span>
        {% endif %}

        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarsMenu"
            aria-controls="navbarsMenu" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>

        <div class="collapse navbar-collapse flex-column ml-auto" id="navbarsMenu">
            <ul class="navbar-nav">

                <!-- block menu -->
                <li class="nav-item">
                    {% include "modules/menu.html" %}
                </li>
                <!-- endblock -->

                <!-- block search -->
                <li class="nav-item">
                    <a class="collapsed" data-bs-toggle="collapse" href="#collapseExample" role="button" aria-expanded="false" aria-controls="collapseExample">
                        <div class="md-search-icon">
                            <i class="fa fa-search" aria-hidden="true"></i>
                        </div>
                    </a>
                </li>
                <!--  endblock -->

                <!-- block source -->
                <li class="nav-item">
                    {% if config.repo_url %}
                        {% if config.repo_name != 'GitHub' %}
                            {% include "modules/source.html" %}
                        {% endif %}
                    {% endif %}
                </li>
                <!--  endblock -->
            </ul>
        </div>
    </div>
</nav>
<!--  endblock -->