{% extends "main.html" %}

{% block content %}
    <!-- block search -->
	<section class="p-md-5 content-search">
		<article class="search-box">
			<p></p>
			<h1 id="search">Search Results</h1>
			<hr>

			<form id="content_search" action="search.html">
				<span role="status" aria-live="polite" class="ui-helper-hidden-accessible"></span>
				<input name="q" id="mkdocs-search-query" type="text" class="search-query search_input search-query ui-autocomplete-input"
					placeholder="Search the Docs" autocomplete="off" autofocus title="Type search term here">
			</form>

			<div id="mkdocs-search-results" class="search-results" data-no-results-text="No results found">
				Searching...
			</div>

		</article>
	</section>
    <!-- endblock -->
{% endblock %}