<!-- block menu -->
{%- if nav|length>1 %}
    {% if config.theme.components and config.theme.components.menu == False %}
    {% else %}
        <li class="nav-item" id="component-menu">
            <ul class="navbar-nav">
                {%- for nav_item in nav %}
                    {%- if nav_item.children %}
                        <li class="nav-item dropdown">
                            <a class="{% if nav_item.active %} active {% endif %}
                            nav-link dropdown-toggle text-decoration-none" href="#" data-bs-toggle="dropdown">[{{ nav_item.title }}]</a>
                            <ul class="dropdown-menu">
                                {%- for nav_item in nav_item.children %}
                                    {% include "modules/dropdown-menu.html" %}
                                {%- endfor %}
                            </ul>
                        </li>
                    {%- else %}
                        <li class="nav-item">
                            <a class="{% if nav_item.active %} active {% endif %}
                            nav-link text-gray text-decoration-none" href="{{ nav_item.url|url }}">[{{ nav_item.title }}]</a>
                        </li>
                    {%- endif %}
                {%- endfor %}
            </ul>
        </li>
    {%- endif %}
{%- endif %}
<!-- endblock -->
